/**
 * @description Show fields that are related to the passed value and hide the other
 *
 * @param {HTMLElement} form - The form containing the fields
 * @param {string} type - Type that should be shown
 */
function updateShownFields(form, type) {
    const fields = form.querySelectorAll('[data-block-type]');

    fields.forEach((field) => {
        const row = field.closest('.field');

        row.style.display = field.dataset.blockType === type ? 'block' : 'none';
    });
}


// eslint-disable-next-line no-undef
document.addEventListener('monsieurBizRichEditorInitForm', (e) => {
    const { form } = e.detail;
    const typeSelect = form.querySelector('[data-block-select-type]');

    if (typeSelect) {
        updateShownFields(form, typeSelect.value);

        typeSelect.addEventListener('change', (event) => {
            updateShownFields(form, event.target.value);
        });
    }
});
